@@ -11,6 +11,7 @@
 set -x -e
 set -o pipefail
 
+INCLUDE_PATH="${PREFIX}/include"
 LIBRARY_PATH="${PREFIX}/lib"
 
 # Always build PIC code for enable static linking into other shared libraries
@@ -22,15 +23,25 @@ elif [ "$(uname)" == "Linux" ]; then
     TOOLSET=gcc
 fi
 
+# http://www.boost.org/build/doc/html/bbv2/tasks/crosscompile.html
+cat <<EOF > ${SRC_DIR}/tools/build/src/site-config.jam
+using ${TOOLSET} : : ${CXX} ;
+EOF
+
 LINKFLAGS="${LINKFLAGS} -L${LIBRARY_PATH}"
 
 ./bootstrap.sh \
     --prefix="${PREFIX}" \
+    --with-toolset=cc \
     --with-icu="${PREFIX}" \
     --with-python="${PYTHON}" \
     --with-python-root="${PREFIX} : ${PREFIX}/include/python${PY_VER}m ${PREFIX}/include/python${PY_VER}" \
     2>&1 | tee bootstrap.log
 
+# https://svn.boost.org/trac10/ticket/5917
+# https://stackoverflow.com/a/5244844/1005215
+sed -i.bak "s,cc,${TOOLSET},g" ${SRC_DIR}/project-config.jam
+
 ./b2 -q \
     variant=release \
     address-model="${ARCH}" \
@@ -41,6 +52,7 @@ LINKFLAGS="${LINKFLAGS} -L${LIBRARY_PATH}"
     link=static,shared \
     toolset=${TOOLSET} \
     python="${PY_VER}" \
+    include="${INCLUDE_PATH}" \
     cxxflags="${CXXFLAGS}" \
     linkflags="${LINKFLAGS}" \
     --layout=system \
